#ifndef _AUDIO_SOURCES
#define _AUDIO_SOURCES

#include <glib.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>

#define DEFAULT_AUDIO_SOURCE "pulsesrc"

// Types of audio devices
enum DeviceType {
    NOT_DEFINED  = 0x0,
    DEFAULT_DEVICE = 0x1, // Desktop's default device.
    AUDIO_SINK = 0x2,     // Real audio card with sound output, audio sink (audio card with loudspeakers).
    AUDIO_RECEIVER = 0x4, // This "device" can receive audio from another computer in the net (over tcp or uds). NOT YET IMPLEMENTED.
    AUDIO_SOURCE = 0x8,   // Standalone microphone or webcam with microphone, etc. Also audio-cards that we can tap sound of (all *.monitor devices).
    MEDIA_PLAYER = 0x10   // DBus entity. Media Players like RhythmBox, Amarok and Banshee, also Skype. These can control the recording via DBus.
};

typedef struct {
    enum DeviceType type; // Device type.
    gchar *id;            // Internal device id (audio device). In Pulseaudio this field is called "name".
    gchar *description;   // Human readable device description shown in the combo.
    gint sink_index;      // Pulseaudio.c: this index points from g_source_list to g_sink_list.
} DeviceItem;

DeviceItem *device_item_create(gchar *id, gchar *name);
DeviceItem *device_item_copy_node(DeviceItem *item);
void device_item_free(DeviceItem *item);
const gchar *device_item_get_type_name(guint type);

// ComboBox columns
enum {
    COL_DEVICE_TYPE,    // DeviceType (see above), hidden column
    COL_DEVICE_ID,      // Device ID, hidden column
    COL_DEVICE_DESCR,   // Device description, visible column
    N_DEVICE_COLUMNS    // Number of columns in the combobox
};

gboolean filter_for_sink_dev(DeviceItem *item);

void audio_sources_init();
void audio_sources_exit();

void audio_sources_free_list(GList *lst);
void audio_sources_print_list(GList *list, gchar *tag);
void audio_sources_print_list_ex();

DeviceItem *audio_sources_find_id(gchar *device_id);

GList *audio_sources_get_for_type(gint type);

typedef gboolean (*DeviceItemFilterFunc)(DeviceItem *item);
GList *audio_sources_get_with_filter(DeviceItemFilterFunc filter_func);

void audio_sources_device_changed(gchar *device_id);
void audio_sources_get_device(gchar **audio_source, gchar **device_id);

GtkWidget *audio_sources_create_combo();
void audio_source_fill_combo(GtkWidget *combo);
void audio_sources_combo_set_id(GtkWidget *combo, gchar *device_id);
gint audio_sources_get_combo_index(GtkWidget *combo);
gboolean audio_sources_combo_get_values(GtkWidget *combo, gchar **device_name, gchar **device_id, gint *device_type);

#endif



